@@ -75,6 +75,7 @@ def heal(packagename: str, t: str) -> None:  # pragma: no cover
         [f"prettify-py format-dir {packagename}"], shell=True, check=True)
     if t == "y":
         subprocess.run(["python -m pytest tests/"], shell=True, check=True)
+    say_end_message()
 
 
 @click.command()
@@ -98,9 +99,13 @@ def deploy(t: str) -> None:
     subprocess.run(["python3 -m build"], shell=True, check=True)
     subprocess.run(["twine check dist/*"], shell=True, check=True)
     subprocess.run(["python3 -m twine upload dist/*"], shell=True, check=True)
+    say_end_message()
 
 
 def say_message() -> None:
+    """
+    Console message for information about the project
+    """
 
     anatomical_heart = emojize(":anatomical_heart:")
     mechanical_arm = emojize(":mechanical_arm:")
@@ -116,6 +121,26 @@ def say_message() -> None:
     echo(message=message)
 
 
+def say_end_message() -> None:
+    """
+    Goodbye message
+    """
+    anatomical_heart = emojize(":anatomical_heart:")
+    mechanical_arm = emojize(":mechanical_arm:")
+    call_me_hand = emojize(":call_me_hand:")
+    sailing_ship = emojize(":sailboat:")
+
+    message = (
+        f"Thank you for using Lia."
+        f"{anatomical_heart} Lia is an open-source CI/CD tool "
+        f"that eliminates the Fel {mechanical_arm}\n"
+        f" Copyright © 2023 Soul Twin Records {call_me_hand}, "
+        f"a subsidiary of SailBlack Inc. {sailing_ship}"
+        f"For more nice things follow us on www.codeberg.org/sail.black"
+    )
+    echo(message=message)
+
+
 spells.add_command(heal)
 spells.add_command(deploy)
 
